@@ -176,7 +176,7 @@ def without(dict_in: dict, keys: list):
         keys = [keys]
     new_d = dict_in.copy()
     for key in keys:
-        new_d.pop(key)
+        new_d.pop(key, None)
     return new_d
 
 
