@@ -82,20 +82,11 @@ def test_initialize_dataset_2d():
     assert set(dataset.coords.keys()) == {"x0", "x1"}
 
 
-def test_getset_datadir(tmp_test_data_dir):
-    # here to ensure we always start with default datadir
-    dh._datadir = None
-
-    with pytest.raises(NotADirectoryError):
-        # Ensure users are forced to pick a datadir in order to avoid
-        # potential dataloss
-        dh.get_datadir()
-
-    new_dir_path = os.path.join(tmp_test_data_dir, "test_datadir2")
-    os.mkdir(new_dir_path)
+def test_set_datadir(tmp_test_data_dir):
+    # Test valid directory creation
+    new_dir_path = os.path.join(tmp_test_data_dir, "test_datadir")
     dh.set_datadir(new_dir_path)
-    assert os.path.split(dh.get_datadir())[-1] == "test_datadir2"
-    os.rmdir(new_dir_path)
+    assert os.access(new_dir_path, os.W_OK)
 
     # Test setting to None
     dh.set_datadir(None)
@@ -110,6 +101,20 @@ def test_getset_datadir(tmp_test_data_dir):
         dh.set_datadir("")
 
 
+def test_get_datadir(tmp_test_data_dir):
+    dh._datadir = None
+
+    with pytest.raises(NotADirectoryError):
+        # Ensure users are forced to pick a datadir in order to avoid
+        # potential dataloss
+        dh.get_datadir()
+
+    new_dir_path = os.path.join(tmp_test_data_dir, "test_datadir2")
+    os.mkdir(new_dir_path)
+    dh.set_datadir(new_dir_path)
+    assert os.path.split(dh.get_datadir())[-1] == "test_datadir2"
+
+
 def test_load_dataset(tmp_test_data_dir):
     dh.set_datadir(tmp_test_data_dir)
     tuid = "20200430-170837-001-315f36"
