@@ -10,13 +10,19 @@ import pytest
 
 
 def test_header() -> None:
-    skipfiles = {"__init__.py", "conftest.py", "setup.py"}
+    skipfiles = {
+        "__init__.py",
+        "conftest.py",
+        "setup.py",
+        "_version.py",
+        "_static_version.py",
+    }
     skipdirs = {"docs", ".", "tests", "__pycache__", "venv"}
     failures = []
     quantify_core_path = Path(__file__).resolve().parent.parent.resolve()
     header_lines = [
         "# Repository: https://gitlab.com/quantify-os/quantify-core",
-        "# Licensed according to the LICENCE file on the master branch",
+        "# Licensed according to the LICENCE file on the main branch",
     ]
     for root, _, files in os.walk(quantify_core_path):
         # skip hidden folders, etc
